Index: modules/stream_out/transcode.c
===================================================================
--- modules/stream_out/transcode.c	(rvision 18533)
+++ modules/stream_out/transcode.c	(copie de travail)
@@ -124,6 +124,10 @@
     "This sets aspect (like 4:3) of the video canvas and letterbox the video "\
     "accordingly." )
 
+#define ASPECT_TEXT N_("Force an output aspect ratio")
+#define ASPECT_LONGTEXT N_("Overrides and sets the video aspect flag "\
+    "in the output stream.")
+
 #define AENC_TEXT N_("Audio encoder")
 #define AENC_LONGTEXT N_( \
     "This is the audio encoder module that will be used (and its associated "\
@@ -255,6 +259,9 @@
     add_string( SOUT_CFG_PREFIX "canvas-aspect", NULL, NULL, CANVAS_ASPECT_TEXT,
                 CANVAS_ASPECT_LONGTEXT, VLC_FALSE );
 
+    add_string( SOUT_CFG_PREFIX "aspect-override", NULL, NULL, ASPECT_TEXT,
+                ASPECT_LONGTEXT, VLC_FALSE );
+
     set_section( N_("Audio"), NULL );
     add_string( SOUT_CFG_PREFIX "aenc", NULL, NULL, AENC_TEXT,
                 AENC_LONGTEXT, VLC_FALSE );
@@ -298,7 +305,7 @@
 static const char *ppsz_sout_options[] = {
     "venc", "vcodec", "vb", "croptop", "cropbottom", "cropleft", "cropright",
     "paddtop", "paddbottom", "paddleft", "paddright", 
-    "canvas-width", "canvas-height", "canvas-aspect", 
+    "canvas-width", "canvas-height", "canvas-aspect", "aspect-override",
     "scale", "fps", "width", "height", "vfilter", "deinterlace",
     "deinterlace-module", "threads", "hurry-up", "aenc", "acodec", "ab",
     "afilter", "samplerate", "channels", "senc", "scodec", "soverlay",
@@ -418,6 +425,8 @@
     int             i_canvas_height;
     int             i_canvas_aspect;
 
+    int             i_aspect_override;
+
     /* Video, calculated */
     int             i_src_x_offset;
     int             i_src_y_offset;
@@ -681,7 +690,23 @@
 
     }
     if( val.psz_string ) free( val.psz_string );
+    
+    var_Get( p_stream, SOUT_CFG_PREFIX "aspect-override", &val );
+    p_sys->i_aspect_override = 0;
+    if( val.psz_string && *val.psz_string )
+    {
+        char *psz_parser = strchr( val.psz_string, ':' );
+        if( psz_parser )
+        {
+            *psz_parser++ = '\0';
+            p_sys->i_aspect_override = atoi( val.psz_string ) *
+                VOUT_ASPECT_FACTOR / atoi( psz_parser );
+        }
+        else msg_Warn( p_stream, "bad aspect ratio %s", val.psz_string );
 
+    }
+    if( val.psz_string ) free( val.psz_string );
+
     var_Get( p_stream, SOUT_CFG_PREFIX "threads", &val );
     p_sys->i_threads = val.i_int;
     var_Get( p_stream, SOUT_CFG_PREFIX "high-priority", &val );
@@ -1991,7 +2016,14 @@
     /* Check whether a particular aspect ratio was requested */
     if( !id->p_encoder->fmt_out.video.i_aspect )
     {
-        id->p_encoder->fmt_out.video.i_aspect = (int)( f_aspect * VOUT_ASPECT_FACTOR + 0.5 );
+        if( p_sys->i_aspect_override )
+        {
+            id->p_encoder->fmt_out.video.i_aspect = p_sys->i_aspect_override;
+        }
+        else
+        {
+            id->p_encoder->fmt_out.video.i_aspect = (int)( f_aspect * VOUT_ASPECT_FACTOR + 0.5 );
+        }
     }
     id->p_encoder->fmt_in.video.i_aspect =
         id->p_encoder->fmt_out.video.i_aspect;
